@@ -9,7 +9,7 @@
 
 package Glib::GenPod;
 
-our $VERSION = '1.323';
+our $VERSION = '1.326';
 
 use strict;
 use warnings;
@@ -40,7 +40,7 @@ our @EXPORT = qw(
 our $COPYRIGHT = undef;
 our $AUTHORS = 'Gtk2-Perl Team';
 our $MAIN_MOD = undef;
-our $YEAR = strftime "%Y", gmtime;
+our $YEAR = strftime "%Y", gmtime($ENV{SOURCE_DATE_EPOCH} || time);
 
 our ($xspods, $data);
 	
@@ -244,7 +244,7 @@ sub xsdoc2pod
 	die "usage: $0 datafile [outdir]\n"
 		unless defined $datafile;
 
-	require $datafile;
+	require "./$datafile";
 
 	my @files = ();
 
@@ -877,7 +877,7 @@ pod will be still be placed there.
 This function is called at all of the specified points through out the process
 of generating pod for a page. Any pod matching the I<position> passed will be
 returned, undef if no matches were found.  If I<position> is undef all pods
-without sepcific postion information will be returned. I<pods> is a reference
+without specific position information will be returned. I<pods> is a reference
 to an array of pod hashes.
 
 =over
